@@ -3,6 +3,9 @@ import pickle
 import platform
 
 import logging
+
+import pymongo.errors
+
 logger = logging.getLogger(__name__)
 formatter = logging.Formatter('%(levelname)s: [%(name)s] %(message)s')
 ch = logging.StreamHandler()
@@ -127,3 +130,13 @@ def set_default():
     print(s)
     with open(FULL_PATH, "wb") as fw:
         pickle.dump(s, fw)
+
+
+def is_srv_live(addr: str) -> bool:
+    from pymongo import MongoClient
+    try:
+        client = MongoClient(addr)
+        r = client.db_name.command('ping')
+        return True
+    except pymongo.errors.ServerSelectionTimeoutError:
+        return False
\ No newline at end of file
